@@ -8,36 +8,8 @@ show_gmm_curve <- function(spect_em_gmm_res, x, y, mix_ratio_init, mu_init, sigm
   cal_time        <- spect_em_gmm_res$cal_time
   K               <- length(es_mu_G)
 
-  #Plotting fitting curve
-  #par(mfrow = c(1,1))
-
-  esGMM_EM <- matrix(NA, nrow = K, ncol = length(x))
-  for(k in 1:K) {
-    esGMM_EM[k, ] <- es_mix_ratio_G[k] * dnorm(x = x, mean = es_mu_G[k], sd = es_sigma_G[k])
-  }
-
-  esGMM   <- colSums(esGMM_EM)
-
-  esGMM_c   <- matrix(NA, nrow = K, ncol = length(x))
-  for(k in 1:K) {
-    esGMM_c[k,] <- esGMM_EM[k,] * sum(y) / sum(esGMM)
-  }
-
-  Est_spect_G    <- colSums(esGMM_c)
-  Energy_G       <- x
-
-  for(k in 1:K) {
-    plot(esGMM_c[k,]~Energy_G, pch=19,  xlim = c(min(x), max(x)), ylim = c(0, max(y)), col = "black", las = 1, typ = "l", lwd = 2, cex = 0.75, lty = 3, ylab = "Frequency", xlab = "x", main = "")
-    par(new = TRUE)
-  }
-
-  plot(Est_spect_G~Energy_G, pch=19,  xlim = c(min(x), max(x)), ylim = c(0, max(y)), col = "tomato3", las = 1, typ = "l", lwd = 2, cex = 0.75, ylab = "Frequency", xlab = "x", main = "Estimted GMM")
-  par(new = TRUE)
-  plot(y~Energy_G, pch=21,  xlim = c(min(x), max(x)), ylim = c(0, max(y)), col = "black", las = 1, typ = "p", lwd = 2, cex = 0.75, ylab = "Frequency", xlab = "x")
-
-  #Plotting trace plot of the parameters
+  #Fitting curve
   cols <- colorRamp(c("#ff4b00", "#fff100", "#03af7a", "#005aff"))
-  #par(mfrow = c(3,2))
 
   esGMM_EM <- matrix(NA, nrow = K, ncol = length(x))
   for(k in 1:K) {
@@ -61,7 +33,7 @@ show_gmm_curve <- function(spect_em_gmm_res, x, y, mix_ratio_init, mu_init, sigm
 
   plot(Est_spect_G~x_G, pch=19,  xlim = c(min(x), max(x)), ylim = c(0, max(y)), col = "tomato3", las = 1, typ = "l", lwd = 2, cex = 0.75, ylab = "Frequency", xlab = "x", main = "Estimted GMM")
   par(new = TRUE)
-  plot(y~Energy_G, pch=21,  xlim = c(min(x), max(x)), ylim = c(0, max(y)), col = "black", las = 1, typ = "p", lwd = 2, cex = 0.75, ylab = "Frequency", xlab = "x")
+  plot(y~x_G, pch=21,  xlim = c(min(x), max(x)), ylim = c(0, max(y)), col = "black", las = 1, typ = "p", lwd = 2, cex = 0.75, ylab = "Frequency", xlab = "x")
 
   plot(spect_em_gmm_res$LL, ylab = "L", xlab = "iteration")
 
